if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded zlibtcl 1.3.1 [list load [file join $dir libtcl9zlibtcl131.so]]
} else {
    package ifneeded zlibtcl 1.3.1 [list load [file join $dir libzlibtcl131.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded pngtcl 1.6.48 [list load [file join $dir libtcl9pngtcl1648.so]]
} else {
    package ifneeded pngtcl 1.6.48 [list load [file join $dir libpngtcl1648.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded tifftcl 4.7.0 [list load [file join $dir libtcl9tifftcl470.so]]
} else {
    package ifneeded tifftcl 4.7.0 [list load [file join $dir libtifftcl470.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded jpegtcl 9.6.0 [list load [file join $dir libtcl9jpegtcl960.so]]
} else {
    package ifneeded jpegtcl 9.6.0 [list load [file join $dir libjpegtcl960.so]]
}
# -*- tcl -*- Tcl package index file
# --- --- --- Handcrafted, final generation by configure.

if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::base 2.1.0 [list load [file join $dir libtcl9tkimg210.so]]
} else {
    package ifneeded img::base 2.1.0 [list load [file join $dir libtkimg210.so]]
}
# Compatibility hack. When asking for the old name of the package
# then load all format handlers and base libraries provided by tkImg.
# Actually we ask only for the format handlers, the required base
# packages will be loaded automatically through the usual package
# mechanism.

# When reading images without specifying it's format (option -format),
# the available formats are tried in reversed order as listed here.
# Therefore file formats with some "magic" identifier, which can be
# recognized safely, should be added at the end of this list.

package ifneeded Img 2.1.0 {
    package require img::window
    package require img::tga
    package require img::ico
    package require img::pcx
    package require img::sgi
    package require img::sun
    package require img::xbm
    package require img::xpm
    package require img::jpeg
    package require img::png
    package require img::tiff
    package require img::bmp
    package require img::ppm
    package require img::pixmap
    package provide Img 2.1.0
}

if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::bmp 2.1.0 [list load [file join $dir libtcl9tkimgbmp210.so]]
} else {
    package ifneeded img::bmp 2.1.0 [list load [file join $dir libtkimgbmp210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::gif 2.1.0 [list load [file join $dir libtcl9tkimggif210.so]]
} else {
    package ifneeded img::gif 2.1.0 [list load [file join $dir libtkimggif210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::ico 2.1.0 [list load [file join $dir libtcl9tkimgico210.so]]
} else {
    package ifneeded img::ico 2.1.0 [list load [file join $dir libtkimgico210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::jpeg 2.1.0 [list load [file join $dir libtcl9tkimgjpeg210.so]]
} else {
    package ifneeded img::jpeg 2.1.0 [list load [file join $dir libtkimgjpeg210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::pcx 2.1.0 [list load [file join $dir libtcl9tkimgpcx210.so]]
} else {
    package ifneeded img::pcx 2.1.0 [list load [file join $dir libtkimgpcx210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::pixmap 2.1.0 [list load [file join $dir libtcl9tkimgpixmap210.so]]
} else {
    package ifneeded img::pixmap 2.1.0 [list load [file join $dir libtkimgpixmap210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::png 2.1.0 [list load [file join $dir libtcl9tkimgpng210.so]]
} else {
    package ifneeded img::png 2.1.0 [list load [file join $dir libtkimgpng210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::ppm 2.1.0 [list load [file join $dir libtcl9tkimgppm210.so]]
} else {
    package ifneeded img::ppm 2.1.0 [list load [file join $dir libtkimgppm210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::ps 2.1.0 [list load [file join $dir libtcl9tkimgps210.so]]
} else {
    package ifneeded img::ps 2.1.0 [list load [file join $dir libtkimgps210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::sgi 2.1.0 [list load [file join $dir libtcl9tkimgsgi210.so]]
} else {
    package ifneeded img::sgi 2.1.0 [list load [file join $dir libtkimgsgi210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::sun 2.1.0 [list load [file join $dir libtcl9tkimgsun210.so]]
} else {
    package ifneeded img::sun 2.1.0 [list load [file join $dir libtkimgsun210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::tga 2.1.0 [list load [file join $dir libtcl9tkimgtga210.so]]
} else {
    package ifneeded img::tga 2.1.0 [list load [file join $dir libtkimgtga210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::tiff 2.1.0 [list load [file join $dir libtcl9tkimgtiff210.so]]
} else {
    package ifneeded img::tiff 2.1.0 [list load [file join $dir libtkimgtiff210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::window 2.1.0 [list load [file join $dir libtcl9tkimgwindow210.so]]
} else {
    package ifneeded img::window 2.1.0 [list load [file join $dir libtkimgwindow210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::xbm 2.1.0 [list load [file join $dir libtcl9tkimgxbm210.so]]
} else {
    package ifneeded img::xbm 2.1.0 [list load [file join $dir libtkimgxbm210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::xpm 2.1.0 [list load [file join $dir libtcl9tkimgxpm210.so]]
} else {
    package ifneeded img::xpm 2.1.0 [list load [file join $dir libtkimgxpm210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::dted 2.1.0 [list load [file join $dir libtcl9tkimgdted210.so]]
} else {
    package ifneeded img::dted 2.1.0 [list load [file join $dir libtkimgdted210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::raw 2.1.0 [list load [file join $dir libtcl9tkimgraw210.so]]
} else {
    package ifneeded img::raw 2.1.0 [list load [file join $dir libtkimgraw210.so]]
}
if {[package vsatisfies [package provide Tcl] 9.0-]} {
    package ifneeded img::flir 2.1.0 [list load [file join $dir libtcl9tkimgflir210.so]]
} else {
    package ifneeded img::flir 2.1.0 [list load [file join $dir libtkimgflir210.so]]
}
